@@ -1,6 +1,6 @@
 ;;; org-transclusion.el --- Transclude text content via links -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2021-2022  Free Software Foundation, Inc.
+;; Copyright (C) 2021-2023  Free Software Foundation, Inc.
 
 ;; This program is free software: you can redistribute it and/or modify it
 ;; under the terms of the GNU General Public License as published by the
@@ -17,12 +17,12 @@
 
 ;; Author:        Noboru Ota <me@nobiot.com>
 ;; Created:       10 October 2020
-;; Last modified: 12 June 2022
+;; Last modified: 05 February 2023
 
 ;; URL: https://github.com/nobiot/org-transclusion
 ;; Keywords: org-mode, transclusion, writing
 
-;; Version: 1.3.0
+;; Version: 1.3.2
 ;; Package-Requires: ((emacs "27.1") (org "9.4"))
 
 ;; This file is not part of GNU Emacs.
@@ -864,9 +864,10 @@ keyword.  If not, returns nil."
     (setq custom-properties-string
           (dolist (fn org-transclusion-keyword-plist-to-string-functions
                       custom-properties-string)
-            (when-let ((str (funcall fn plist)))
-              (setq custom-properties-string
-                    (concat custom-properties-string " " str )))))
+            (let ((str (funcall fn plist)))
+              (when (and str (not (string-empty-p str)))
+                (setq custom-properties-string
+                      (concat custom-properties-string " " str ))))))
     (concat "#+transclude: "
             link
             (when level (format " :level %d" level))
